@@ -7,7 +7,9 @@
 #include <umem.h>
 #define cache_t umem_cache_t
 #define cache_alloc(a) umem_cache_alloc(a, UMEM_DEFAULT)
+#define do_cache_alloc(a) umem_cache_alloc(a, UMEM_DEFAULT)
 #define cache_free(a, b) umem_cache_free(a, b)
+#define do_cache_free(a, b) umem_cache_free(a, b)
 #define cache_create(a,b,c,d,e) umem_cache_create((char*)a, b, c, d, e, NULL, NULL, NULL, 0)
 #define cache_destroy(a) umem_cache_destroy(a);
 
