@@ -351,6 +351,10 @@ static pid_t start_server(in_port_t *port_out, bool daemon, int timeout) {
         }
 #ifdef MESSAGE_DEBUG
          argv[arg++] = "-vvv";
+#endif
+#ifdef HAVE_DROP_PRIVILEGES
+        argv[arg++] = "-o";
+        argv[arg++] = "relaxed_privileges";
 #endif
         argv[arg++] = NULL;
         assert(execv(argv[0], argv) != -1);
